==> knotR_1.0-1.tar.gz: knotR/man/knots.Rd <==
\name{knots}
\alias{knots}
\alias{k10_123}
\alias{k11a179}
\alias{k3_1}
\alias{k3_1a}
\alias{k4_1}
\alias{k5_1}
\alias{k5_2}
\alias{k6_1}
\alias{k6_2}
\alias{k6_3}
\alias{k7_1}
\alias{k7_2}
\alias{k7_3}
\alias{k7_4}
\alias{k7_5}
\alias{k7_6}
\alias{k7_7}
\alias{k8_1}
\alias{k8_2}
\alias{k8_3}
\alias{k8_4}
\alias{k8_5}
\alias{k8_6}
\alias{k8_7}
\alias{k8_8}
\alias{k8_9}
\alias{k8_10}
\alias{k8_11}
\alias{k8_12}
\alias{k8_13}
\alias{k8_14}
\alias{k8_15}
\alias{k8_16}
\alias{k8_17}
\alias{k8_18}
\alias{k8_19}
\alias{k8_19a}
\alias{k8_20}
\alias{k8_21}
\alias{k9_1}
\alias{k9_2}
\alias{k9_3}
\alias{k9_4}
\alias{k9_5}
\alias{k9_6}
\alias{k9_7}
\alias{k9_8}
\alias{k9_9}
\alias{k9_10}
\alias{k9_11}
\alias{k9_12}
\alias{k9_13}
\alias{k9_14}
\alias{k9_15}
\alias{k9_16}
\alias{k9_17}
\alias{k9_18}
\alias{k9_22}
\alias{k9_23}
\alias{k9_34}
\alias{k9_35}
\alias{k10_61}
\alias{k10_1}
\alias{k11n157}
\alias{k11n157_morenodes}
\alias{k11n22}
\alias{k11a361}
\alias{k12n_0242}
\alias{k12n_0411}
\alias{k_infinity}
\alias{ochiai}
\alias{ornamental20}
\alias{perko_A}
\alias{perko_B}
\alias{pretzel_2_3_7}
\alias{pretzel_7_3_7}
\alias{product_knot}
\alias{amphichiral15}
\alias{satellite}
\alias{three_figure_eights}
\alias{unknot}
\alias{D16}
\docType{data}
\title{Optimized knots}
\description{A variety of knots with optimized forms}
\details{

  A selection of knots that have been optimized for visual appearance.
  The list makes no claims for completeness; the examples are intended
  to show the abilities of the package.

  Knots with names like \code{k7_3} use the naming scheme of Rolfsen.

  Knots with names like \code{k11n157} follow the nomenclature of the
  Hoste-Thistlethwaite table;  \sQuote{a}  means \sQuote{alternating}
  and \sQuote{n} means \sQuote{nonalternating}.
  
  Knot \code{k12a_614} is drawn from the \dQuote{Table of Knot
    Invariants} by Livingstone and Cha.
  
  Knot \code{amphichiral15} is the unique amphichiral knot with crossing
  number 15, due to Hoste, Thistlethwaite, and Weeks.

  Knots \code{k12n_0411} and \code{k11a203} show that partial symmetry
  may be enforced.

  Knot \code{k8_18} is an exceptional knot.

  Knot \code{pretzel_p3_p5_p7_m3_m5} is drawn from a knot appearing in
  Bryant 2016.  The notation specifies the sense (\sQuote{p} for plus
  and \sQuote{m} for minus) of the twists.
  

}
\references{
\itemize{
\item J. C. Cha and C. Livingston. \emph{KnotInfo: Table of Knot Invariants},
\url{http://www.indiana.edu/~knotinfo}, July 7, 2016
\item K. A. Bryant, 2016. \emph{Slice implies mutant-ribbon for odd,
  5-stranted pretzel knots}, \code{arXiv:1511.07009v2}}

}

\examples{
knotplot(k3_1)
## maybe str(k3_1) ; plot(k3_1) ...
}
\keyword{datasets}

==> knotR_1.0-2.tar.gz: knotR/man/knots.Rd <==
\name{knots}
\alias{knots}
\alias{k3_1}
\alias{k3_1a}
\alias{k4_1}
\alias{k5_1}
\alias{k5_2}
\alias{k6_1}
\alias{k6_2}
\alias{k6_3}
\alias{k7_1}
\alias{k7_2}
\alias{k7_3}
\alias{k7_4}
\alias{k7_5}
\alias{k7_6}
\alias{k7_7}
\alias{k7_7a}
\alias{k8_1}
\alias{k8_2}
\alias{k8_3}
\alias{k8_4}
\alias{k8_4a}
\alias{k8_5}
\alias{k8_6}
\alias{k8_7}
\alias{k8_8}
\alias{k8_9}
\alias{k8_10}
\alias{k8_11}
\alias{k8_12}
\alias{k8_13}
\alias{k8_14}
\alias{k8_15}
\alias{k8_16}
\alias{k8_17}
\alias{k8_18}
\alias{k8_19}
\alias{k8_19a}
\alias{k8_20}
\alias{k8_21}
\alias{k9_1}
\alias{k9_2}
\alias{k9_3}
\alias{k9_4}
\alias{k9_5}
\alias{k9_6}
\alias{k9_7}
\alias{k9_8}
\alias{k9_9}
\alias{k9_10}
\alias{k9_11}
\alias{k9_12}
\alias{k9_13}
\alias{k9_14}
\alias{k9_15}
\alias{k9_16}
\alias{k9_17}
\alias{k9_18}
\alias{k9_19}
\alias{k9_20}
\alias{k9_21}
\alias{k9_22}
\alias{k9_23}
\alias{k9_24}
\alias{k9_25}
\alias{k9_26}
\alias{k9_27}
\alias{k9_28}
\alias{k9_29}
\alias{k9_30}
\alias{k9_31}
\alias{k9_32}
\alias{k9_33}
\alias{k9_34}
\alias{k9_35}
\alias{k9_36}
\alias{k9_37}
\alias{k9_38}
\alias{k9_39}
\alias{k9_40}
\alias{k9_41}
\alias{k9_42}
\alias{k9_43}
\alias{k9_44}
\alias{k9_45}
\alias{k9_46}
\alias{k9_47}
\alias{k9_48}
\alias{k9_49}
\alias{k10_1}
\alias{k10_47}
\alias{k10_61}
\alias{k10_61a}
\alias{k10_123}
\alias{k11a179}
\alias{k11a361}
\alias{k11a1}
\alias{k11n157}
\alias{k11n157_morenodes}
\alias{k11n22}
\alias{k12n_0242}
\alias{k12n_0411}
\alias{celtic3}
\alias{k_infinity}
\alias{fourloops}
\alias{fiveloops}
\alias{flower}
\alias{longthin}
\alias{ochiai}
\alias{ornamental20}
\alias{perko_A}
\alias{perko_B}
\alias{pretzel_2_3_7}
\alias{pretzel_7_3_7}
\alias{pretzel_p3_p5_p7_m3_m5}
\alias{product_knot}
\alias{reefknot}
\alias{amphichiral15}
\alias{satellite}
\alias{sum_31_41}
\alias{three_figure_eights}
\alias{trefoil_of_trefoils}
\alias{triloop}
\alias{unknot}
\alias{D16}
\alias{T20}
\docType{data}
\title{Optimized knots}
\description{A variety of knots with optimized forms}
\details{

  A selection of knots that have been optimized for visual appearance.
  The list makes no claims for completeness; the examples are intended
  to show the abilities of the package.

  Knots with names like \code{k7_3} use the naming scheme of Rolfsen.

  Knots with names like \code{k11n157} follow the nomenclature of the
  Hoste-Thistlethwaite table;  \sQuote{a}  means \sQuote{alternating}
  and \sQuote{n} means \sQuote{nonalternating}.
  
  Knot \code{k12a_614} is drawn from the \dQuote{Table of Knot
    Invariants} by Livingstone and Cha.
  
  Knot \code{amphichiral15} is the unique amphichiral knot with crossing
  number 15, due to Hoste, Thistlethwaite, and Weeks.

  Knots \code{k12n_0411} and \code{k11a203} show that partial symmetry
  may be enforced.

  Knot \code{k8_18} is an exceptional knot.

  Knot \code{pretzel_p3_p5_p7_m3_m5} is drawn from a knot appearing in
  Bryant 2016.  The notation specifies the sense (\sQuote{p} for plus
  and \sQuote{m} for minus) of the twists.

  Knot \code{T20} is a \dQuote{remarkable 20-crossing tangle}; see references

}
\references{
\itemize{
\item J. C. Cha and C. Livingston. \emph{KnotInfo: Table of Knot Invariants},
\url{http://www.indiana.edu/~knotinfo}, July 7, 2016
\item K. A. Bryant, 2016. \emph{Slice implies mutant-ribbon for odd,
  5-stranted pretzel knots}, \code{arXiv:1511.07009v2}
\item{S. Eliahou and J. Fromentin 2017. \dQuote{A remarkable 20-crossing
    tangle}.  Arxiv, \url{https://arxiv.org/abs/1610.05560v2}
}
}
}

\examples{
knotplot(k3_1)
## maybe str(k3_1) ; plot(k3_1) ...
}
\keyword{datasets}
